@@ -2,15 +2,17 @@ import mimetypes
 from base64 import b64encode
 from datetime import datetime
 from email.mime.base import MIMEBase
-from email.utils import formatdate, parseaddr, unquote
+from email.utils import formatdate, getaddresses, unquote
 from time import mktime
 
 import six
 from django.conf import settings
 from django.core.mail.message import sanitize_address, DEFAULT_ATTACHMENT_MIME_TYPE
+from django.utils.encoding import force_text
+from django.utils.functional import Promise
 from django.utils.timezone import utc
 
-from .exceptions import AnymailConfigurationError
+from .exceptions import AnymailConfigurationError, AnymailInvalidAddress
 
 UNSET = object()  # Used as non-None default value
 
@@ -93,31 +95,39 @@ def getfirst(dct, keys, default=UNSET):
         return default
 
 
+def parse_one_addr(address):
+    # This is email.utils.parseaddr, but without silently returning
+    # partial content if there are commas or parens in the string:
+    addresses = getaddresses([address])
+    if len(addresses) > 1:
+        raise ValueError("Multiple email addresses (parses as %r)" % addresses)
+    elif len(addresses) == 0:
+        return ('', '')
+    return addresses[0]
+
+
 class ParsedEmail(object):
-    """A sanitized, full email address with separate name and email properties"""
+    """A sanitized, full email address with separate name and email properties."""
 
     def __init__(self, address, encoding):
-        self.address = sanitize_address(address, encoding)
-        self._name = None
-        self._email = None
-
-    def _parse(self):
-        if self._email is None:
-            self._name, self._email = parseaddr(self.address)
+        if address is None:
+            self.name = self.email = self.address = None
+            return
+        try:
+            self.name, self.email = parse_one_addr(force_text(address))
+            if self.email == '':
+                # normalize sanitize_address py2/3 behavior:
+                raise ValueError('No email found')
+            # Django's sanitize_address is like email.utils.formataddr, but also
+            # escapes as needed for use in email message headers:
+            self.address = sanitize_address((self.name, self.email), encoding)
+        except (IndexError, TypeError, ValueError) as err:
+            raise AnymailInvalidAddress("Invalid email address format %r: %s"
+                                        % (address, str(err)))
 
     def __str__(self):
         return self.address
 
-    @property
-    def name(self):
-        self._parse()
-        return self._name
-
-    @property
-    def email(self):
-        self._parse()
-        return self._email
-
 
 class Attachment(object):
     """A normalized EmailMessage.attachments item with additional functionality
@@ -153,6 +163,9 @@ class Attachment(object):
         else:
             (self.name, self.content, self.mimetype) = attachment
 
+        self.name = force_non_lazy(self.name)
+        self.content = force_non_lazy(self.content)
+
         # Guess missing mimetype from filename, borrowed from
         # django.core.mail.EmailMessage._create_attachment()
         if self.mimetype is None and self.name is not None:
@@ -280,3 +293,37 @@ def rfc2822date(dt):
     # but treats naive datetimes as local rather than "UTC with no information ..."
     timeval = timestamp(dt)
     return formatdate(timeval, usegmt=True)
+
+
+def is_lazy(obj):
+    """Return True if obj is a Django lazy object."""
+    # See django.utils.functional.lazy. (This appears to be preferred
+    # to checking for `not isinstance(obj, six.text_type)`.)
+    return isinstance(obj, Promise)
+
+
+def force_non_lazy(obj):
+    """If obj is a Django lazy object, return it coerced to text; otherwise return it unchanged.
+
+    (Similar to django.utils.encoding.force_text, but doesn't alter non-text objects.)
+    """
+    if is_lazy(obj):
+        return six.text_type(obj)
+
+    return obj
+
+
+def force_non_lazy_list(obj):
+    """Return a (shallow) copy of sequence obj, with all values forced non-lazy."""
+    try:
+        return [force_non_lazy(item) for item in obj]
+    except (AttributeError, TypeError):
+        return force_non_lazy(obj)
+
+
+def force_non_lazy_dict(obj):
+    """Return a (deep) copy of dict obj, with all values forced non-lazy."""
+    try:
+        return {key: force_non_lazy_dict(value) for key, value in obj.items()}
+    except (AttributeError, TypeError):
+        return force_non_lazy(obj)
